Library Documentation
=====================

Thorough documentation on the *command-line* interfaces exists in :ref:`this page <command-line interfaces>`. Here the **taurenmd** internals are documented, you may use them independently for a more advanced developer use.

.. automodule:: taurenmd.libs

.. toctree::
    :glob:

    core
    lib*
